@@ -669,9 +669,6 @@ class BiCoN(object):
 
                             else:  # terminate if no improvement
                                 move = False
-                                print("network {0} has converged".format(clust))
-                                print(score1)
-                                print(nx.is_connected(nx.subgraph(G,nodes)))
                         else:
                             nodes = nodes0
                             move = False
